Crate hid_types

Crate hid_types 

Rust types for working with USB HID report descriptors.

This crate contains Rust types for encoding and decoding USB HID (Human Interface Device) report descriptors. It contains all of the constants from the HID specifications, as well as code to encode and decode binary report descriptors.

It’s mostly intended for use by the hid-descriptor and hid-decode crates.

See Device Class Definition for Human Interface Devices for a detailed description of HID report descriptors.

Modules

encoding
Details of descriptor item encoding.
hid
HID descriptor items.
id
The id module contains enums with identification numbers used in USB HID descriptors.
item
HID Report Descriptor Items

Enums

Ident
A container that holds either a known variant, or an integer value with unknown meaning.