TypeBits

Enum TypeBits 

#[repr(u8)]
pub enum TypeBits { Main = 0, Global = 1, Local = 2, Reserved = 3, }
The bits specifying the type of an item.

Variants



Main = 0



Global = 1



Local = 2



Reserved = 3

Implementations

Source

impl TypeBits

pub const fn into_bits(self) -> u8

Convert the TypeBits into an integer in the encoded form.

pub const fn from_bits(value: u8) -> Self

Decode encoded type bits.

The input values allowed are the same as those in the binary report descriptor (0-3).

Panics

This function will panic if the input is out of the range 0-3.