pub fn encode_signed(data: &[u8]) -> &[u8] ⓘExpand description
An integer value, in little-endian variable length form.
Drops any trailing zero bytes, if that leaves the last byte with its most-significant bit 0.
Drops any trailing 0xFF bytes, if that leaves the last byte with the
most-significant bit set.
Because this is a signed value, leading zeros can only be dropped if the following byte doesn’t have the sign bit (MSB) set.