Ident

Enum Ident 

pub enum Ident<T, Repr> {
    Known(T),
    Reserved(Repr),
}
A container that holds either a known variant, or an integer value with unknown meaning.

Variants



Known(T)

A well-known Usage ID.



Reserved(Repr)

A reserved Usage ID.

This can be used to identify vendor-specific types.

Implementations

Source

impl<T, Repr> Ident<T, Repr>
where T: TryFrom<Repr>, Repr: Clone + Copy,

pub fn from_integer(value: Repr) -> Self

Try to decode a known identifier; if that fails store the raw number as a “reserved” value.

Source

impl<T> Ident<T, u8>
where T: Into<u8>,

pub fn to_integer(self) -> u8

Convert the identifier to an integer.

Source

impl<T> Ident<T, u16>
where T: Into<u16>,

pub fn to_integer(self) -> u16

Convert the identifier to an integer.