Module ioflags

Module ioflags 

A collection of shorthand types for specifying input/output/feature item flags.

These are not required (IoFlags may be used instead) but because it may not be clear what the default flags are, these values may improve readability.

Constants

ARRAY
Input/Output/Feature flags for a data array, using the terminology common in USB HID standards.
CONSTANT
Input/Output/Feature flags for a constant, using the terminology common in USB HID standards.
DATA_VARIABLE_ABSOLUTE
Input/Output/Feature flags, using the terminology common in USB HID standards.