Module item

Module item 

HID Report Descriptor Items

This module contains fully populated descriptor items (containing values). See the hid module for just the item ID values.

Modules

usage
Types that contain all the information in Usage tags.

Structs

LongItem
An item using the “long” encoding.

Enums

Global
A Global item.
Item
An HID report descriptor Item.
Local
A Local item.
Main
A Main item.