pub enum Item {
Long(LongItem),
Main(Main),
Global(Global),
Local(Local),
Reserved(u8),
}Expand description
An HID report descriptor Item.
Variants
Long(LongItem)
An undecoded “long” item.
According to the spec (Device Class Definition for Human Interface Devices, section 6.2.2.3), there are no standard-defined uses for this encoding.
Main(Main)
A Main item.
See Device Class Definition for Human Interface Devices, section 6.2.2.4.
Global(Global)
A Global item.
Local(Local)
A Local item.
Reserved(u8)
A reserved item value.
This should not be used; the descriptor cannot be properly decoded.
Implementations