Types that contain all the information in Usage tags.
Structs
- Extended
Usage - A Usage ID, that includes its parent Usage Page.
Enums
- Known
Usage - A well-known usage id.
- Usage
- A Usage ID, that does not encode its parent page.
Types that contain all the information in Usage tags.