pub struct ExtendedUsage {
pub page: UsagePage,
pub id: u16,
}Expand description
A Usage ID, that includes its parent Usage Page.
Fields
page: UsagePageThe Usage Page.
id: u16The Usage ID.
Implementations
Sourceimpl ExtendedUsage
impl ExtendedUsage
Sourcepub fn get_known(&self) -> Option<KnownUsage>
pub fn get_known(&self) -> Option<KnownUsage>
Extract the usage value if it is a known value.
If this returns None it could be for multiple reasons:
- The Usage Page does not contain distinct IDs (e.g. Button)
- The Usage Page is unknown or reserved.
- The Usage Page is known but the Usage value is unknown or reserved.