HID Report Descriptor Items
This module contains fully populated descriptor items (containing values).
See the hid module for just the item ID values.
Modules
- usage
- Types that contain all the information in Usage tags.
Structs
- Long
Item - An item using the “long” encoding.