ExtendedUsage

Struct ExtendedUsage 

pub struct ExtendedUsage {
    pub page: UsagePage,
    pub id: u16,
}
A Usage ID, that includes its parent Usage Page.

Fields

page: UsagePage

The Usage Page.

id: u16

The Usage ID.

Implementations

Source

impl ExtendedUsage

pub fn new(page: UsagePage, id: u16) -> Self

Create a new ExtendedUsage value.

pub fn from_u32(value: u32) -> Self

Construct a usage page/id from a single integer

pub fn get_known(&self) -> Option<KnownUsage>

Extract the usage value if it is a known value.

If this returns None it could be for multiple reasons:

  1. The Usage Page does not contain distinct IDs (e.g. Button)
  2. The Usage Page is unknown or reserved.
  3. The Usage Page is known but the Usage value is unknown or reserved.